.hide-spinner[data-v-ed9712b1]::-webkit-outer-spin-button,.hide-spinner[data-v-ed9712b1]::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.hide-spinner[data-v-ed9712b1]{-moz-appearance:textfield}
