import{r as m,h as b,ad as g,g as a,e as l,a2 as p,M as y}from"./vendor-vue-gvI8EVHg.js";import{_ as K}from"./AppLayout.vue_vue_type_script_setup_true_lang-B-qRa1uC.js";import{X as f}from"./index-DCLQfd0E.js";import{u as h}from"./vendor-i18n-DnQQ95F5.js";/* empty css                                                                  */import"./vendor-misc-DVqRnJX7.js";import"./LocaleSwitcher-Bv3UnTZV.js";/* empty css                                                                       */const k={class:"h-[calc(100vh-5.5rem)] min-h-[720px] overflow-hidden rounded-[1.5rem] border border-slate-200 bg-white shadow-sm dark:border-dark-700 dark:bg-dark-900"},v={class:"h-full bg-slate-50 dark:bg-dark-900"},w=["src","title"],I=m({__name:"EmbeddedPortalView",setup(S){const{t:i}=h(),t=p(),c=f(),o={jobs:{enabledKey:"jobs_portal_enabled",urlKey:"jobs_portal_url",slug:"jobs"},finance:{enabledKey:"finance_portal_enabled",urlKey:"finance_portal_url",slug:"finance"},legalAdvisor:{enabledKey:"legal_advisor_enabled",urlKey:"legal_advisor_url",slug:"legal-advisor"},learningCourse:{enabledKey:"learning_course_enabled",urlKey:"learning_course_url",slug:"learning-course"},chatAvatar:{enabledKey:"chat_avatar_enabled",urlKey:"chat_avatar_url",slug:"chat-avatar"},comicDrama:{enabledKey:"comic_drama_enabled",urlKey:"comic_drama_url",slug:"comic-drama"},skillsAgentMarket:{enabledKey:"skills_agent_market_enabled",urlKey:"skills_agent_market_url",slug:"skills-agent-market"},creatorService:{enabledKey:"creator_service_enabled",urlKey:"creator_service_url",slug:"creator-service"},ticketSubmit:{enabledKey:"ticket_submit_enabled",urlKey:"ticket_submit_url",slug:"ticket-submit"}},u=l(()=>{const e=String(t.meta.portalType||"jobs");return o[e]?e:"jobs"}),d=l(()=>String(t.meta.titleKey||"embeddedPortal.jobs.title")),s=l(()=>{const e=c.cachedPublicSettings,r=o[u.value],_=!!(e!=null&&e[r.enabledKey]),n=String((e==null?void 0:e[r.urlKey])||"").trim();return{title:i(d.value),url:_&&n?n:`/portal-coming-soon?portal=${encodeURIComponent(r.slug)}`}});return(e,r)=>(y(),b(K,null,{default:g(()=>[a("div",k,[a("section",v,[a("iframe",{src:s.value.url,title:s.value.title,class:"h-full w-full border-0 bg-white",loading:"eager",referrerpolicy:"strict-origin-when-cross-origin"},null,8,w)])])]),_:1}))}});export{I as default};
