import{f as r}from"./index-DCLQfd0E.js";async function o(t){const a={code:t},{data:e}=await r.post("/redeem",a);return e}async function n(){const{data:t}=await r.get("/redeem/history");return t}async function s(t){const a={code:t},{data:e}=await r.post("/redeem-workflow/verify-card",a);return e}const i={redeem:o,getHistory:n,verifyWorkflowCard:s};export{i as r};
