.custom-scrollbar[data-v-484aa3d3]{scrollbar-width:thin;scrollbar-color:rgba(156,163,175,.3) transparent}.custom-scrollbar[data-v-484aa3d3]::-webkit-scrollbar{width:6px}.custom-scrollbar[data-v-484aa3d3]::-webkit-scrollbar-track{background:transparent}.custom-scrollbar[data-v-484aa3d3]::-webkit-scrollbar-thumb{background-color:#9ca3af4d;border-radius:3px}.custom-scrollbar[data-v-484aa3d3]::-webkit-scrollbar-thumb:hover{background-color:#9ca3af80}.compact-select .select-trigger{border-radius:.5rem;padding:.375rem .75rem;font-size:.75rem;line-height:1rem}
