import{c as g}from"./index-DCLQfd0E.js";import{u as p}from"./vendor-i18n-DnQQ95F5.js";import{r as x,h,ad as c,g as t,Y as o,S as y,D as k,e as i,M as b}from"./vendor-vue-gvI8EVHg.js";const w={class:"space-y-4"},C={class:"text-sm text-gray-600 dark:text-gray-400"},v={class:"flex justify-end space-x-3"},S=x({__name:"ConfirmDialog",props:{show:{type:Boolean},title:{},message:{},confirmText:{},cancelText:{},danger:{type:Boolean,default:!1}},emits:["confirm","cancel"],setup(e,{emit:d}){const{t:r}=p(),s=e,f=i(()=>s.confirmText||r("common.confirm")),m=i(()=>s.cancelText||r("common.cancel")),a=d,l=()=>{a("confirm")},n=()=>{a("cancel")};return(u,_)=>(b(),h(g,{show:e.show,title:e.title,width:"narrow",onClose:n},{footer:c(()=>[t("div",v,[t("button",{onClick:n,type:"button",class:"rounded-md border border-gray-300 bg-white px-4 py-2 text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-primary-500 focus:ring-offset-2 dark:border-dark-600 dark:bg-dark-700 dark:text-gray-200 dark:hover:bg-dark-600 dark:focus:ring-offset-dark-800"},o(m.value),1),t("button",{onClick:l,type:"button",class:k(["rounded-md px-4 py-2 text-sm font-medium text-white focus:outline-none focus:ring-2 focus:ring-offset-2 dark:focus:ring-offset-dark-800",e.danger?"bg-red-600 hover:bg-red-700 focus:ring-red-500":"bg-primary-600 hover:bg-primary-700 focus:ring-primary-500"])},o(f.value),3)])]),default:c(()=>[t("div",w,[t("p",C,o(e.message),1),y(u.$slots,"default")])]),_:3},8,["show","title"]))}});export{S as _};
