import{f as i}from"./index-DCLQfd0E.js";async function a(){const{data:t}=await i.get("/invite-commission/summary");return t}async function s(){const{data:t}=await i.get("/invite-commission/tree");return t}async function o(t={}){const{data:n}=await i.get("/invite-commission/records",{params:t});return n}async function c(t={}){const{data:n}=await i.get("/invite-commission/invitees",{params:t});return n}async function r(){const{data:t}=await i.get("/invite-commission/points");return t}async function m(t={}){const{data:n}=await i.get("/invite-commission/points/changes",{params:t});return n}async function g(t,n){const{data:e}=await i.post("/invite-commission/points/transfer-to-balance",t,{headers:{"Idempotency-Key":n}});return e}const y={getSummary:a,getTreeSummary:s,getInvitees:c,getRecords:o,getPointsSummary:r,getPointsChanges:m,transferPointsToBalance:g};export{r as g,y as i};
