import{r,J as d,L as c,j as s,S as o,i,g as l,D as u,P as v,M as t}from"./vendor-vue-gvI8EVHg.js";import{a as m}from"./index-DCLQfd0E.js";const _={key:0,class:"layout-section-fixed"},p={key:1,class:"layout-section-fixed"},f={class:"layout-section-scrollable"},y={class:"card table-scroll-container"},b={key:2,class:"layout-section-fixed"},h=r({__name:"TablePageLayout",setup($){const n=v(!1),a=()=>{n.value=window.innerWidth<1024};return d(()=>{a(),window.addEventListener("resize",a)}),c(()=>{window.removeEventListener("resize",a)}),(e,g)=>(t(),s("div",{class:u(["table-page-layout",{"mobile-mode":n.value}])},[e.$slots.actions?(t(),s("div",_,[o(e.$slots,"actions",{},void 0,!0)])):i("",!0),e.$slots.filters?(t(),s("div",p,[o(e.$slots,"filters",{},void 0,!0)])):i("",!0),l("div",f,[l("div",y,[o(e.$slots,"table",{},void 0,!0)])]),e.$slots.pagination?(t(),s("div",b,[o(e.$slots,"pagination",{},void 0,!0)])):i("",!0)],2))}}),L=m(h,[["__scopeId","data-v-75248971"]]);export{L as T};
