import{b as u}from"./index-DCLQfd0E.js";import{u as d}from"./vendor-ui-BBVLefJs.js";import{r as p,j as i,g as o,p as m,M as h}from"./vendor-vue-gvI8EVHg.js";const f={class:"relative w-full"},_={class:"pointer-events-none absolute inset-y-0 left-0 flex items-center pl-3"},v=["value","placeholder"],g=p({__name:"SearchInput",props:{modelValue:{},placeholder:{default:"Search..."},debounceMs:{default:300}},emits:["update:modelValue","search"],setup(t,{emit:l}){const n=t,s=l,c=d(e=>{s("search",e)},n.debounceMs),r=e=>{const a=e.target.value;s("update:modelValue",a),c(a)};return(e,a)=>(h(),i("div",f,[o("div",_,[m(u,{name:"search",size:"md",class:"text-gray-400"})]),o("input",{value:t.modelValue,type:"text",class:"input pl-10",placeholder:t.placeholder,onInput:r},null,40,v)]))}});export{g as _};
