import{r as g,j as f,S as l,h as x,T as v,ae as w,aa as h,g as o,E as m,P as s,a4 as y,C as k,M as n,o as b,Y as B}from"./vendor-vue-gvI8EVHg.js";const T=g({__name:"HelpTooltip",props:{content:{}},setup(i){const r=s(!1),p=y("trigger"),a=s({top:"0px",left:"0px"});function d(){r.value=!0,k(c)}function u(){r.value=!1}function c(){const t=p.value;if(!t)return;const e=t.getBoundingClientRect();a.value={top:`${e.top+window.scrollY}px`,left:`${e.left+e.width/2+window.scrollX}px`}}return(t,e)=>(n(),f("div",{ref:"trigger",class:"group relative ml-1 inline-flex items-center align-middle",onMouseenter:d,onMouseleave:u},[l(t.$slots,"trigger",{},()=>[e[0]||(e[0]=o("svg",{class:"h-4 w-4 cursor-help text-gray-400 transition-colors hover:text-primary-600 dark:text-gray-500 dark:hover:text-primary-400",fill:"none",viewBox:"0 0 24 24",stroke:"currentColor","stroke-width":"2"},[o("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"})],-1))]),(n(),x(v,{to:"body"},[w(o("div",{class:"fixed z-[99999] w-64 -translate-x-1/2 -translate-y-full rounded-lg bg-gray-900 p-3 text-xs leading-relaxed text-white shadow-xl ring-1 ring-white/10 dark:bg-gray-800",style:m({top:`calc(${a.value.top} - 8px)`,left:a.value.left})},[l(t.$slots,"default",{},()=>[b(B(i.content),1)]),e[1]||(e[1]=o("div",{class:"absolute -bottom-1 left-1/2 h-2 w-2 -translate-x-1/2 rotate-45 bg-gray-900 dark:bg-gray-800"},null,-1))],4),[[h,r.value]])]))],544))}});export{T as _};
