import{_ as m}from"./GroupBadge.vue_vue_type_script_setup_true_lang-C5ARZGJV.js";import{r as p,j as a,g as s,p as x,Y as i,i as l,D as f,F as n,o as k,e as c,M as r}from"./vendor-vue-gvI8EVHg.js";import{a as g}from"./index-DCLQfd0E.js";const y={class:"flex min-w-0 flex-1 items-start justify-between gap-3"},h=["title"],b={key:0,class:"mt-1.5 w-full text-left text-xs leading-relaxed text-gray-500 dark:text-gray-400 line-clamp-2"},v={class:"flex shrink-0 items-center gap-2 pt-0.5"},w={class:"mr-1 line-through opacity-50"},M={class:"font-bold"},C={key:1,class:"h-4 w-4 shrink-0 text-primary-600 dark:text-primary-400",fill:"none",stroke:"currentColor",viewBox:"0 0 24 24","stroke-width":"2"},B=p({__name:"GroupOptionItem",props:{name:{},platform:{},subscriptionType:{default:"standard"},rateMultiplier:{},userRateMultiplier:{default:null},description:{},selected:{type:Boolean,default:!1},showCheckmark:{type:Boolean,default:!0}},setup(e){const t=e,d=c(()=>t.userRateMultiplier!==null&&t.userRateMultiplier!==void 0&&t.rateMultiplier!==void 0&&t.userRateMultiplier!==t.rateMultiplier),u=c(()=>{switch(t.platform){case"anthropic":return"bg-amber-50 text-amber-700 dark:bg-amber-900/20 dark:text-amber-400";case"openai":return"bg-green-50 text-green-700 dark:bg-green-900/20 dark:text-green-400";case"gemini":return"bg-sky-50 text-sky-700 dark:bg-sky-900/20 dark:text-sky-400";case"sora":return"bg-rose-50 text-rose-700 dark:bg-rose-900/20 dark:text-rose-400";default:return"bg-violet-50 text-violet-700 dark:bg-violet-900/20 dark:text-violet-400"}});return(R,o)=>(r(),a("div",y,[s("div",{class:"flex min-w-0 flex-1 flex-col items-start",title:e.description||void 0},[x(m,{name:e.name,platform:e.platform,"subscription-type":e.subscriptionType,"show-rate":!1,class:"groupOptionItemBadge"},null,8,["name","platform","subscription-type"]),e.description?(r(),a("span",b,i(e.description),1)):l("",!0)],8,h),s("div",v,[e.rateMultiplier!==void 0?(r(),a("span",{key:0,class:f(["inline-flex items-center whitespace-nowrap rounded-full px-3 py-1 text-xs font-semibold",u.value])},[d.value?(r(),a(n,{key:0},[s("span",w,i(e.rateMultiplier)+"x",1),s("span",M,i(e.userRateMultiplier)+"x",1)],64)):(r(),a(n,{key:1},[k(i(e.rateMultiplier)+"x 倍率 ",1)],64))],2)):l("",!0),e.showCheckmark&&e.selected?(r(),a("svg",C,[...o[0]||(o[0]=[s("path",{"stroke-linecap":"round","stroke-linejoin":"round",d:"M5 13l4 4L19 7"},null,-1)])])):l("",!0)])]))}}),j=g(B,[["__scopeId","data-v-ec9371a3"]]);export{j as G};
