.table-wrapper[data-v-41924826]{--select-col-width: 52px;position:relative;overflow-x:auto;overflow-y:auto;flex:1;min-height:0;isolation:isolate}.table-wrapper .table-header[data-v-41924826]{position:sticky;top:0;z-index:200;background-color:#f9fafb}.dark .table-wrapper .table-header[data-v-41924826]{background-color:#1f2937}.table-body[data-v-41924826]{position:relative;z-index:0}.sticky-header-cell[data-v-41924826]{position:sticky;top:0;z-index:210;background-color:#f9fafb}.dark .sticky-header-cell[data-v-41924826]{background-color:#1f2937}.sticky-col[data-v-41924826]{position:sticky;z-index:20}.sticky-col-left[data-v-41924826],.sticky-col-left-first[data-v-41924826]{left:0}.sticky-col-left-second[data-v-41924826]{left:var(--select-col-width)}.sticky-col-right[data-v-41924826]{right:0}.sticky-header-cell.sticky-col[data-v-41924826]{z-index:220}tbody .sticky-col[data-v-41924826]{background-color:#fff}.dark tbody .sticky-col[data-v-41924826]{background-color:#111827}tbody tr:hover .sticky-col[data-v-41924826]{background-color:#f9fafb}.dark tbody tr:hover .sticky-col[data-v-41924826]{background-color:#1f2937}.is-scrollable .sticky-col-left[data-v-41924826]:after{content:"";position:absolute;top:0;right:0;bottom:0;width:10px;transform:translate(100%);background:linear-gradient(to right,rgba(0,0,0,.08),transparent);pointer-events:none}.is-scrollable .sticky-col-left-second[data-v-41924826]:after{content:"";position:absolute;top:0;right:0;bottom:0;width:10px;transform:translate(100%);background:linear-gradient(to right,rgba(0,0,0,.08),transparent);pointer-events:none}.is-scrollable .sticky-col-right[data-v-41924826]:before{content:"";position:absolute;top:0;left:0;bottom:0;width:10px;transform:translate(-100%);background:linear-gradient(to left,rgba(0,0,0,.08),transparent);pointer-events:none}.dark .is-scrollable .sticky-col-left[data-v-41924826]:after,.dark .is-scrollable .sticky-col-left-second[data-v-41924826]:after{background:linear-gradient(to right,rgba(0,0,0,.2),transparent)}.dark .is-scrollable .sticky-col-right[data-v-41924826]:before{background:linear-gradient(to left,rgba(0,0,0,.2),transparent)}
