.spinner[data-v-ad54ea09]{display:inline-block;border-radius:9999px;border-style:solid;border-color:currentColor;border-right-color:transparent;animation:spin-ad54ea09 .75s linear infinite}@keyframes spin-ad54ea09{0%{transform:rotate(0)}to{transform:rotate(360deg)}}
