import{r as l,j as s,D as o,g as i,M as u}from"./vendor-vue-gvI8EVHg.js";const c=["aria-checked"],g=l({__name:"Toggle",props:{modelValue:{type:Boolean}},emits:["update:modelValue"],setup(e,{emit:n}){const a=e,t=n;function r(){t("update:modelValue",!a.modelValue)}return(d,m)=>(u(),s("button",{type:"button",onClick:r,class:o(["relative inline-flex h-6 w-11 flex-shrink-0 cursor-pointer rounded-full border-2 border-transparent transition-colors duration-200 ease-in-out focus:outline-none focus:ring-2 focus:ring-primary-500 focus:ring-offset-2 dark:focus:ring-offset-dark-800",[e.modelValue?"bg-primary-600":"bg-gray-200 dark:bg-dark-600"]]),role:"switch","aria-checked":e.modelValue},[i("span",{class:o(["pointer-events-none inline-block h-5 w-5 transform rounded-full bg-white shadow ring-0 transition duration-200 ease-in-out",[e.modelValue?"translate-x-5":"translate-x-0"]])},null,2)],10,c))}});export{g as _};
