.docs-shell[data-v-e64d49de]{position:relative}.terminal-panel[data-v-e64d49de]{box-shadow:0 30px 80px #00000073,inset 0 1px #ffffff0f}.terminal-head[data-v-e64d49de]{display:flex;align-items:center;justify-content:space-between;border-bottom:1px solid rgba(255,255,255,.08);color:#71717a;font-size:12px;letter-spacing:.14em;padding-bottom:12px;text-transform:uppercase}.terminal-dots[data-v-e64d49de]{display:flex;gap:8px}.terminal-dots span[data-v-e64d49de]{display:inline-block;width:10px;height:10px;border-radius:999px}.terminal-dots span[data-v-e64d49de]:nth-child(1){background:#fb7185}.terminal-dots span[data-v-e64d49de]:nth-child(2){background:#fbbf24}.terminal-dots span[data-v-e64d49de]:nth-child(3){background:#4ade80}.terminal-body[data-v-e64d49de]{font-family:SFMono-Regular,Menlo,Monaco,Consolas,monospace;font-size:14px;line-height:1.9;padding-top:16px}.terminal-prompt[data-v-e64d49de]{color:#f4f4f5}.terminal-cmd[data-v-e64d49de]{color:#93c5fd}.terminal-comment[data-v-e64d49de]{color:#71717a}.terminal-success[data-v-e64d49de]{color:#6ee7b7}.terminal-text[data-v-e64d49de]{color:#e4e4e7}.docs-prose[data-v-e64d49de] p{margin:0 0 1rem}.docs-prose[data-v-e64d49de] a{color:#5eead4;font-weight:600;text-decoration:none}.docs-prose[data-v-e64d49de] a:hover{text-decoration:underline}.docs-prose[data-v-e64d49de] strong{color:#fafafa}.docs-prose[data-v-e64d49de] code{border:1px solid rgba(255,255,255,.08);border-radius:.75rem;background:#ffffff0f;color:#fafafa;font-family:SFMono-Regular,Menlo,Monaco,Consolas,monospace;font-size:.92em;padding:.15rem .45rem}.docs-prose[data-v-e64d49de] ul,.docs-prose[data-v-e64d49de] ol{margin:0 0 1.25rem;padding-left:1.4rem}.docs-prose[data-v-e64d49de] li{margin:.45rem 0}.docs-prose[data-v-e64d49de] h3{margin:1.5rem 0 .75rem;font-size:1.15rem;font-weight:700;color:#fafafa}
