.hide-spinner[data-v-e7ea3cc3]::-webkit-outer-spin-button,.hide-spinner[data-v-e7ea3cc3]::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.hide-spinner[data-v-e7ea3cc3]{-moz-appearance:textfield}
