.custom-page-layout[data-v-000e337e]{display:flex;flex-direction:column;height:calc(100vh - 64px - 4rem)}.custom-embed-shell[data-v-000e337e]{position:relative;height:100%;width:100%;overflow:hidden;border-radius:1rem;background-image:linear-gradient(to bottom,var(--tw-gradient-stops));--tw-gradient-from: #f9fafb var(--tw-gradient-from-position);--tw-gradient-to: rgb(249 250 251 / 0) var(--tw-gradient-to-position);--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to);--tw-gradient-to: #fff var(--tw-gradient-to-position)}.custom-embed-shell[data-v-000e337e]:is(.dark *){--tw-gradient-from: #0f172a var(--tw-gradient-from-position);--tw-gradient-to: rgb(15 23 42 / 0) var(--tw-gradient-to-position);--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to);--tw-gradient-to: #020617 var(--tw-gradient-to-position)}.custom-embed-shell[data-v-000e337e]{padding:0}.custom-open-fab[data-v-000e337e]{position:absolute;right:.75rem;top:.75rem;z-index:10;--tw-shadow: 0 1px 2px 0 rgb(0 0 0 / .05);--tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow);--tw-backdrop-blur: blur(8px);-webkit-backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia);backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia)}@supports (backdrop-filter: var(--tw)){.custom-open-fab[data-v-000e337e]{background-color:#fffc}.custom-open-fab[data-v-000e337e]:is(.dark *){background-color:#1e293bcc}}.custom-embed-frame[data-v-000e337e]{display:block;margin:0;width:100%;height:100%;border:0;border-radius:0;box-shadow:none;background:transparent}
