.table-page-layout[data-v-75248971]{display:flex;flex-direction:column;gap:1.5rem;height:calc(100vh - 64px - 4rem)}.layout-section-fixed[data-v-75248971]{flex-shrink:0}.layout-section-scrollable[data-v-75248971]{display:flex;min-height:0px;flex:1 1 0%;flex-direction:column}.table-scroll-container[data-v-75248971]{display:flex;height:100%;flex-direction:column;overflow:hidden;border-radius:1rem;border-width:1px;--tw-border-opacity: 1;border-color:rgb(229 231 235 / var(--tw-border-opacity, 1));--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity, 1));--tw-shadow: 0 1px 2px 0 rgb(0 0 0 / .05);--tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.table-scroll-container[data-v-75248971]:is(.dark *){--tw-border-opacity: 1;border-color:rgb(51 65 85 / var(--tw-border-opacity, 1));--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity, 1))}.table-scroll-container[data-v-75248971] .table-wrapper{flex:1 1 0%;overflow-x:auto;overflow-y:auto;scrollbar-gutter:stable}.table-scroll-container[data-v-75248971] table{width:100%;min-width:-moz-max-content;min-width:max-content;display:table}.table-scroll-container[data-v-75248971] thead{background-color:#f9fafbcc;--tw-backdrop-blur: blur(4px);-webkit-backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia);backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia)}.table-scroll-container[data-v-75248971] thead:is(.dark *){background-color:#1e293bcc}.table-scroll-container[data-v-75248971] th{border-bottom-width:1px;--tw-border-opacity: 1;border-color:rgb(229 231 235 / var(--tw-border-opacity, 1));padding:1rem 1.25rem;text-align:left;font-size:.875rem;line-height:1.25rem;font-weight:500;--tw-text-opacity: 1;color:rgb(75 85 99 / var(--tw-text-opacity, 1))}.table-scroll-container[data-v-75248971] th:is(.dark *){--tw-border-opacity: 1;border-color:rgb(51 65 85 / var(--tw-border-opacity, 1));--tw-text-opacity: 1;color:rgb(203 213 225 / var(--tw-text-opacity, 1))}.table-scroll-container[data-v-75248971] td{border-bottom-width:1px;--tw-border-opacity: 1;border-color:rgb(243 244 246 / var(--tw-border-opacity, 1));padding:1rem 1.25rem;font-size:.875rem;line-height:1.25rem;--tw-text-opacity: 1;color:rgb(55 65 81 / var(--tw-text-opacity, 1))}.table-scroll-container[data-v-75248971] td:is(.dark *){--tw-border-opacity: 1;border-color:rgb(30 41 59 / var(--tw-border-opacity, 1));--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity, 1))}.table-page-layout.mobile-mode .table-scroll-container[data-v-75248971]{height:auto;overflow:visible;border-style:none;background-color:transparent;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.table-page-layout.mobile-mode .layout-section-scrollable[data-v-75248971]{min-height:-moz-fit-content;min-height:fit-content;flex:none}.table-page-layout.mobile-mode .table-scroll-container[data-v-75248971] .table-wrapper{overflow:visible}.table-page-layout.mobile-mode .table-scroll-container[data-v-75248971] table{flex:none;display:table;min-width:100%}
