.usage-row[data-v-5fc3e120]>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.25rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.25rem * var(--tw-space-y-reverse))}.usage-label[data-v-5fc3e120]{width:2.5rem;flex-shrink:0;font-size:.75rem;line-height:1rem;font-weight:500;--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity, 1))}.usage-label[data-v-5fc3e120]:is(.dark *){--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity, 1))}.usage-amount[data-v-5fc3e120]{white-space:nowrap;font-size:.75rem;line-height:1rem;--tw-numeric-spacing: tabular-nums;font-variant-numeric:var(--tw-ordinal) var(--tw-slashed-zero) var(--tw-numeric-figure) var(--tw-numeric-spacing) var(--tw-numeric-fraction);--tw-text-opacity: 1;color:rgb(75 85 99 / var(--tw-text-opacity, 1))}.usage-amount[data-v-5fc3e120]:is(.dark *){--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity, 1))}.reset-info[data-v-5fc3e120]{display:flex;align-items:center;gap:.25rem;padding-left:3rem;font-size:10px;--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity, 1))}.reset-info[data-v-5fc3e120]:is(.dark *){--tw-text-opacity: 1;color:rgb(96 165 250 / var(--tw-text-opacity, 1))}
