import{X as v,D as b}from"./index-DCLQfd0E.js";import{r as f,J as _,j as l,n as x,g as r,F as y,a1 as k,Y as n,i as c,S as g,e as s,M as d}from"./vendor-vue-gvI8EVHg.js";function w(u,e={}){const t=u.trim();if(!t)return"";if(e.allowRelative&&t.startsWith("/")&&!t.startsWith("//")||e.allowDataUrl&&t.startsWith("data:image/"))return t;if(!t.match(/^https?:\/\//i))return"";try{const o=new URL(t),i=o.protocol.toLowerCase();return i!=="http:"&&i!=="https:"?"":o.toString()}catch{return""}}const L={class:"relative flex min-h-screen items-center justify-center overflow-hidden p-4"},S={class:"relative z-10 w-full max-w-md"},D={class:"mb-8 text-center"},U={class:"mx-auto mb-5 flex h-16 w-16 items-center justify-center overflow-hidden rounded-2xl shadow-lg shadow-primary-500/30 ring-1 ring-white/20 dark:ring-white/10"},A=["src"],N={class:"bg-gradient-to-r from-primary-600 via-primary-500 to-primary-400 bg-clip-text text-3xl font-bold text-transparent dark:from-primary-400 dark:via-primary-300 dark:to-primary-200"},j={key:0,class:"mt-1.5 text-sm text-gray-500 dark:text-dark-400"},F={class:"rounded-2xl border border-white/40 bg-white/80 p-7 shadow-glass backdrop-blur-xl dark:border-dark-700/60 dark:bg-dark-900/70 dark:shadow-glass-lg sm:p-9"},R={key:0,class:"mt-7 text-center text-sm"},z={class:"mt-8 text-center text-xs text-gray-400 dark:text-dark-500"},E=f({__name:"AuthLayout",setup(u){const e=v(),t=s(()=>e.siteName||"Sub2API"),o=s(()=>w(e.siteLogo||"",{allowRelative:!0,allowDataUrl:!0})),i=s(()=>{var a;return((a=e.cachedPublicSettings)==null?void 0:a.site_subtitle)||"The most stable and fastest third-party LLM provider for production use"}),m=s(()=>e.publicSettingsLoaded),h=s(()=>new Date().getFullYear());return _(()=>{e.fetchPublicSettings()}),(a,p)=>(d(),l("div",L,[p[0]||(p[0]=x('<div class="absolute inset-0 bg-gradient-to-br from-gray-50 via-primary-50/30 to-gray-100 dark:from-dark-950 dark:via-dark-900 dark:to-dark-950"></div><div class="pointer-events-none absolute inset-0 overflow-hidden"><div class="absolute -right-40 -top-40 h-80 w-80 animate-pulse rounded-full bg-primary-400/20 blur-3xl"></div><div class="absolute -bottom-40 -left-40 h-80 w-80 animate-pulse rounded-full bg-primary-500/15 blur-3xl" style="animation-delay:2s;"></div><div class="absolute left-1/2 top-1/2 h-96 w-96 -translate-x-1/2 -translate-y-1/2 rounded-full bg-primary-300/10 blur-3xl"></div><div class="absolute inset-0 bg-[linear-gradient(rgba(20,184,166,0.04)_1px,transparent_1px),linear-gradient(90deg,rgba(20,184,166,0.04)_1px,transparent_1px)] bg-[size:48px_48px]"></div></div>',2)),r("div",S,[r("div",D,[m.value?(d(),l(y,{key:0},[r("div",U,[r("img",{src:o.value||k(b),alt:"Logo",class:"h-full w-full object-contain"},null,8,A)]),r("h1",N,n(t.value),1),m.value?(d(),l("p",j,n(i.value),1)):c("",!0)],64)):c("",!0)]),r("div",F,[g(a.$slots,"default")]),a.$slots.footer?(d(),l("div",R,[g(a.$slots,"footer")])):c("",!0),r("div",z," © "+n(h.value)+" "+n(t.value)+". All rights reserved. ",1)])]))}});export{E as _};
