.weekly-hero[data-v-8b2d7218]{position:relative;isolation:isolate}.weekly-hero[data-v-8b2d7218]:before{position:absolute;inset:-35% -10% auto auto;width:34rem;height:34rem;content:"";border-radius:9999px;background:radial-gradient(circle,rgba(251,191,36,.34),rgba(34,211,238,.12) 42%,transparent 68%);filter:blur(2px);z-index:-1}.weekly-hero[data-v-8b2d7218]:after{position:absolute;top:0;right:0;bottom:0;left:0;content:"";background-image:linear-gradient(rgba(255,255,255,.055) 1px,transparent 1px),linear-gradient(90deg,rgba(255,255,255,.055) 1px,transparent 1px);background-size:48px 48px;-webkit-mask-image:linear-gradient(120deg,rgba(0,0,0,.9),transparent 72%);mask-image:linear-gradient(120deg,rgba(0,0,0,.9),transparent 72%);z-index:-2}
