.fade-enter-active[data-v-579dec20],.fade-leave-active[data-v-579dec20]{transition:all .25s ease}.fade-enter-from[data-v-579dec20],.fade-leave-to[data-v-579dec20]{opacity:0;transform:translateY(8px)}.nav-button[data-v-579dec20]{display:inline-flex;align-items:center;justify-content:center;border-radius:.75rem;padding:.625rem 1rem;font-size:.875rem;font-weight:600;transition:all .2s ease}.nav-button[data-v-579dec20]:hover{transform:translateY(-1px)}.nav-button-secondary[data-v-579dec20]{border:1px solid rgb(226 232 240 / .9);background:#ffffffd1;color:#334155}.dark .nav-button-secondary[data-v-579dec20]{border-color:#ffffff1a;background:#0f172aa8;color:#e2e8f0}.nav-button-primary[data-v-579dec20]{background:linear-gradient(135deg,#0f172a,#1e293b);color:#fff;box-shadow:0 18px 38px #0f172a2e}.stat-card[data-v-579dec20]{border-radius:1.25rem;border:1px solid rgb(226 232 240 / .8);background:#f8fafccc;padding:1rem}.dark .stat-card[data-v-579dec20]{border-color:#ffffff1a;background:#ffffff0a}.stat-label[data-v-579dec20]{font-size:.75rem;font-weight:600;letter-spacing:.14em;text-transform:uppercase;color:#64748b}.dark .stat-label[data-v-579dec20]{color:#94a3b8}.stat-value[data-v-579dec20]{margin-top:.5rem;font-size:1.125rem;font-weight:700;color:#0f172a}.dark .stat-value[data-v-579dec20]{color:#fff}.result-card[data-v-579dec20]{display:flex;flex-direction:column;gap:.375rem;border-radius:1rem;border:1px solid rgb(16 185 129 / .16);background:#ffffffa8;padding:.875rem 1rem}.dark .result-card[data-v-579dec20]{border-color:#10b98124;background:#0f172a4d}.result-label[data-v-579dec20]{font-size:.75rem;font-weight:600;letter-spacing:.1em;text-transform:uppercase;color:#059669}.result-value[data-v-579dec20]{font-size:.95rem;font-weight:600;color:#065f46;word-break:break-word}.dark .result-value[data-v-579dec20]{color:#d1fae5}
