import{r as p,j as g,g as e,Y as i,e as a,a2 as u,M as b}from"./vendor-vue-gvI8EVHg.js";import{u as k}from"./vendor-i18n-DnQQ95F5.js";const h={class:"min-h-screen bg-slate-50 text-slate-900 dark:bg-dark-900 dark:text-white"},f={class:"mx-auto flex min-h-screen max-w-4xl items-center px-6 py-16"},x={class:"w-full rounded-[2rem] border border-slate-200 bg-white px-8 py-12 shadow-sm dark:border-dark-700 dark:bg-dark-800"},C={class:"inline-flex rounded-full bg-amber-100 px-3 py-1 text-xs font-semibold tracking-[0.2em] text-amber-700 dark:bg-amber-500/10 dark:text-amber-300"},v={class:"mt-5 text-3xl font-black tracking-tight"},_={class:"mt-4 max-w-2xl text-sm leading-7 text-slate-600 dark:text-dark-200"},S=p({__name:"PortalComingSoonView",setup(w){const{locale:c}=k(),l=u(),s=a(()=>c.value.toLowerCase().startsWith("zh")),d=a(()=>String(l.query.portal||"default")),t=a(()=>{const o={badge:s.value?"敬请期待":"Coming soon"},n={"image-studio":{title:"图文工作台",description:"图文工作台正在维护中，敬请期待。"},jobs:{title:"求职招聘",description:"求职招聘信息页正在准备中，敬请期待。"},finance:{title:"金融看板",description:"金融看板正在准备中，敬请期待。"},"legal-advisor":{title:"律师顾问",description:"律师顾问能力正在准备中，敬请期待。"},"learning-course":{title:"学习课程",description:"学习课程正在准备中，敬请期待。"},"chat-avatar":{title:"和 Mason 聊聊",description:"和 Mason 聊聊能力正在准备中，敬请期待。"},"comic-drama":{title:"漫剧开发",description:"漫剧开发能力正在准备中，敬请期待。"},"skills-agent-market":{title:"skills/agent 市场",description:"skills/agent 市场正在准备中，敬请期待。"},"creator-service":{title:"masoncast",description:"masoncast 正在准备中，敬请期待。"},"ticket-submit":{title:"提交工单",description:"提交工单入口正在准备中，敬请期待。"},default:{title:"页面敬请期待",description:"请稍后再来。"}},m={"image-studio":{title:"Image Studio",description:"Image Studio is under maintenance. Coming soon."},jobs:{title:"Jobs",description:"Jobs and recruiting features are being prepared. Coming soon."},finance:{title:"Finance",description:"Finance dashboard features are being prepared. Coming soon."},"legal-advisor":{title:"Legal Advisor",description:"Legal advisor features are being prepared. Coming soon."},"learning-course":{title:"Learning Course",description:"Learning course features are being prepared. Coming soon."},"chat-avatar":{title:"Chat with Mason",description:"Chat with Mason features are being prepared. Coming soon."},"comic-drama":{title:"Comic Drama Development",description:"Comic drama development features are being prepared. Coming soon."},"skills-agent-market":{title:"Skills/Agent Market",description:"The skills/agent market is being prepared. Coming soon."},"creator-service":{title:"masoncast",description:"masoncast is being prepared. Coming soon."},"ticket-submit":{title:"Submit Ticket",description:"Ticket submission features are being prepared. Coming soon."},default:{title:"Page coming soon",description:"Please check back later."}},r=s.value?n:m;return{...o,...r[d.value]||r.default}});return(o,n)=>(b(),g("div",h,[e("div",f,[e("section",x,[e("div",C,i(t.value.badge),1),e("h1",v,i(t.value.title),1),e("p",_,i(t.value.description),1)])])]))}});export{S as default};
