import{u as i}from"./vendor-i18n-DnQQ95F5.js";import{r as l,j as d,a1 as a,D as p,g as m,Y as u,e as o,M as _}from"./vendor-vue-gvI8EVHg.js";import{a as x}from"./index-DCLQfd0E.js";const g=["aria-label"],f={class:"sr-only"},h=l({__name:"LoadingSpinner",props:{size:{default:"md"},color:{default:"primary"}},setup(t){const{t:e}=i(),s=t,n=o(()=>({sm:"w-4 h-4 border-2",md:"w-8 h-8 border-2",lg:"w-12 h-12 border-[3px]",xl:"w-16 h-16 border-4"})[s.size]),c=o(()=>({primary:"text-primary-500",secondary:"text-gray-500 dark:text-dark-400",white:"text-white",gray:"text-gray-400 dark:text-dark-500"})[s.color]);return(r,y)=>(_(),d("div",{class:p(["spinner",n.value,c.value]),role:"status","aria-label":a(e)("common.loading")},[m("span",f,u(a(e)("common.loading")),1)],10,g))}}),z=x(h,[["__scopeId","data-v-ad54ea09"]]);export{z as L};
