.modal-enter-active[data-v-c87af3b7],.modal-leave-active[data-v-c87af3b7]{transition:opacity .2s ease}.modal-enter-from[data-v-c87af3b7],.modal-leave-to[data-v-c87af3b7]{opacity:0}.dm-drawer-mask-enter-active[data-v-496d33d7],.dm-drawer-mask-leave-active[data-v-496d33d7]{transition:opacity .2s ease}.dm-drawer-mask-enter-from[data-v-496d33d7],.dm-drawer-mask-leave-to[data-v-496d33d7]{opacity:0}.dm-drawer-panel-enter-active[data-v-496d33d7],.dm-drawer-panel-leave-active[data-v-496d33d7]{transition:transform .24s cubic-bezier(.22,1,.36,1),opacity .2s ease}.dm-drawer-panel-enter-from[data-v-496d33d7],.dm-drawer-panel-leave-to[data-v-496d33d7]{opacity:.96;transform:translate(100%)}@media (prefers-reduced-motion: reduce){.dm-drawer-mask-enter-active[data-v-496d33d7],.dm-drawer-mask-leave-active[data-v-496d33d7],.dm-drawer-panel-enter-active[data-v-496d33d7],.dm-drawer-panel-leave-active[data-v-496d33d7]{transition-duration:0s}}.default-sub-group-select[data-v-fa37e508] .select-trigger,.default-sub-delete-btn[data-v-fa37e508]{height:42px}.settings-tabs-scroll[data-v-fa37e508]{scrollbar-width:thin;scrollbar-color:transparent transparent}.settings-tabs-scroll[data-v-fa37e508]:hover{scrollbar-color:rgb(0 0 0 / .15) transparent}:root.dark .settings-tabs-scroll[data-v-fa37e508]:hover{scrollbar-color:rgb(255 255 255 / .2) transparent}.settings-tabs-scroll[data-v-fa37e508]::-webkit-scrollbar{height:3px}.settings-tabs-scroll[data-v-fa37e508]::-webkit-scrollbar-track{background:transparent}.settings-tabs-scroll[data-v-fa37e508]::-webkit-scrollbar-thumb{background:transparent;border-radius:3px}.settings-tabs-scroll[data-v-fa37e508]:hover::-webkit-scrollbar-thumb{background:#00000026}:root.dark .settings-tabs-scroll[data-v-fa37e508]:hover::-webkit-scrollbar-thumb{background:#fff3}.settings-tabs[data-v-fa37e508]{display:inline-flex;min-width:100%;gap:.125rem;border-radius:1rem;border-width:1px;--tw-border-opacity: 1;border-color:rgb(243 244 246 / var(--tw-border-opacity, 1));background-color:#fffc;padding:.25rem;--tw-backdrop-blur: blur(4px);-webkit-backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia);backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia)}.settings-tabs[data-v-fa37e508]:is(.dark *){border-color:#33415580;background-color:#1e293bcc}.settings-tabs[data-v-fa37e508]{box-shadow:0 1px 3px #0000000a,0 1px 2px #00000005}@media (min-width: 640px){.settings-tabs[data-v-fa37e508]{display:flex}}.settings-tab[data-v-fa37e508]{position:relative;display:flex;flex:1 1 0%;align-items:center;justify-content:center;gap:.375rem;white-space:nowrap;border-radius:.75rem;padding:.5rem .625rem;font-size:.875rem;line-height:1.25rem;font-weight:500;--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity, 1));transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.2s;transition-timing-function:cubic-bezier(0,0,.2,1)}.settings-tab[data-v-fa37e508]:is(.dark *){--tw-text-opacity: 1;color:rgb(148 163 184 / var(--tw-text-opacity, 1))}.settings-tab[data-v-fa37e508]:hover:not(.settings-tab-active){--tw-text-opacity: 1;color:rgb(55 65 81 / var(--tw-text-opacity, 1))}.settings-tab[data-v-fa37e508]:hover:not(.settings-tab-active):is(.dark *){--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity, 1))}.settings-tab[data-v-fa37e508]:hover:not(.settings-tab-active){background:#00000008}:root.dark .settings-tab[data-v-fa37e508]:hover:not(.settings-tab-active){background:#ffffff0a}.settings-tab-active[data-v-fa37e508]{--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}.settings-tab-active[data-v-fa37e508]:is(.dark *){--tw-text-opacity: 1;color:rgb(45 212 191 / var(--tw-text-opacity, 1))}.settings-tab-active[data-v-fa37e508]{background:linear-gradient(135deg,#14b8a614,#14b8a608);box-shadow:0 1px 2px #14b8a61a}:root.dark .settings-tab-active[data-v-fa37e508]{background:linear-gradient(135deg,#2dd4bf1f,#2dd4bf0d);box-shadow:0 1px 3px #00000040}.settings-tab-icon[data-v-fa37e508]{display:flex;height:1.5rem;width:1.5rem;align-items:center;justify-content:center;border-radius:.5rem;transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.2s}.settings-tab-active .settings-tab-icon[data-v-fa37e508]{background-color:#14b8a626;--tw-text-opacity: 1;color:rgb(13 148 136 / var(--tw-text-opacity, 1))}.settings-tab-active .settings-tab-icon[data-v-fa37e508]:is(.dark *){background-color:#2dd4bf26;--tw-text-opacity: 1;color:rgb(45 212 191 / var(--tw-text-opacity, 1))}
