import{_ as e}from"./AppLayout.vue_vue_type_script_setup_true_lang-B-qRa1uC.js";import{r as t,h as i,ad as a,g as o,M as s}from"./vendor-vue-gvI8EVHg.js";/* empty css                                                                  */import"./index-DCLQfd0E.js";import"./vendor-misc-DVqRnJX7.js";import"./vendor-i18n-DnQQ95F5.js";import"./LocaleSwitcher-Bv3UnTZV.js";/* empty css                                                                       */const _=t({__name:"ImageStudioEntryView",setup(m){return(d,r)=>(s(),i(e,null,{default:a(()=>[...r[0]||(r[0]=[o("div",{class:"h-[calc(100vh-5.5rem)] min-h-[720px] overflow-hidden rounded-[1.5rem] border border-slate-200 bg-white shadow-sm dark:border-dark-700 dark:bg-dark-900"},[o("iframe",{src:"/portal-coming-soon?portal=image-studio",title:"Image Studio Coming Soon",class:"h-full w-full border-0 bg-white",loading:"eager",referrerpolicy:"strict-origin-when-cross-origin"})],-1)])]),_:1}))}});export{_ as default};
