.fade-enter-active[data-v-1256bdd7],.fade-leave-active[data-v-1256bdd7]{transition:all .3s ease}.fade-enter-from[data-v-1256bdd7],.fade-leave-to[data-v-1256bdd7]{opacity:0;transform:translateY(-8px)}
